## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----echo=F, out.width = "90%"------------------------------------------------
knitr::include_graphics("../man/figure/conbine_1.png")

## ----echo=F, out.width = "100%"-----------------------------------------------
knitr::include_graphics("../man/figure/motif_motify.png")

